@@ -190,6 +190,13 @@ def test_get_frequency_by_time():
     frequency = cm.get_frequency_by_time(10, 0)
     np.testing.assert_allclose(frequency, 0, atol=1.E-8)
 
+    # Ensure we don't throw a hard error in case our requested value
+    # is outside the interpolation range
+    frequency = cm.get_frequency_by_time(0, -1)
+    np.testing.assert_array_equal(frequency, np.nan)
+    frequency = cm.get_frequency_by_time(0, 100)
+    np.testing.assert_array_equal(frequency, np.nan)
+
     times = 10 * np.ones((5, 5, 5, 2, 2, 2))
     positions = np.zeros((5, 5, 5, 2, 2, 2))
     positions[:, :, :, 1, :, :] = 50
@@ -207,6 +214,13 @@ def test_get_frequency_by_time():
     frequency = cm.get_frequency_by_time(10, 0)
     np.testing.assert_allclose(frequency, 10, atol=1.E-8)
 
+    # Ensure we don't throw a hard error in case our requested value
+    # is outside the interpolation range
+    frequency = cm.get_frequency_by_time(0, -1)
+    np.testing.assert_array_equal(frequency, np.nan)
+    frequency = cm.get_frequency_by_time(0, 100)
+    np.testing.assert_array_equal(frequency, np.nan)
+
     times = 10 * np.ones((5, 5, 5, 2, 2, 2))
     positions = np.zeros((5, 5, 5, 2, 2, 2))
     positions[:, :, :, 1, :, :] = 50
@@ -256,6 +270,10 @@ def test_get_position_by_time():
 
     positions = cm.get_position_by_time(0, [10])
     assert positions == [10]
+    positions = cm.get_position_by_time(0, [10.5])
+    assert positions == [10.5]
+    positions = cm.get_position_by_time(5, [10])
+    assert positions == [5]
 
 
 def test_RayleighFitSet_average_fits():
